import PropTypes from 'prop-types';
import React from 'react';
import Waypoint from 'react-waypoint';

import LoadingIndicator from '../../components/loading-indicator';

/**
 * Manually load the data when the loader is clicked on. This is useful as a fallback if the
 * waypoint trigger didn't fire for some reason
 * @param {SyntheticEvent} event
 * @param {Function} onEnter
 */
var handleLoaderClick = function handleLoaderClick(event, onEnter) {
    event.preventDefault();
    onEnter(event);
};

/**
 * Prevent focus on the waypoint to prevent focus from jumping to the bottom of the table when new
 * data is loaded. This means accessibility users can't click on the loading indicator, but they
 * can at least scroll to it. This also means that anything past the bottom of the table cannot be
 * accessed via keyboard controls. This is okay, though, since the infinite scroller should be the
 * last thing in tab order anyway.
 * @param {SyntheticEvent} event
 */
var handleLoaderFocus = function handleLoaderFocus(event) {
    var parent = event.target.parentElement;
    var prev = event.target.previousSibling;
    if (parent && prev) {
        parent.scrollTop = parent.scrollHeight;
        prev.focus();
    }
};

var TableLoader = function TableLoader(_ref) {
    var id = _ref.id,
        onEnter = _ref.onEnter,
        threshold = _ref.threshold;

    if (!onEnter) {
        return React.createElement('span', null);
    }

    return React.createElement(
        'a',
        {
            className: 'table-waypoint',
            onClick: function onClick(event) {
                return handleLoaderClick(event, onEnter);
            },
            onFocus: handleLoaderFocus
        },
        React.createElement(LoadingIndicator, null),
        React.createElement(Waypoint, { key: id, onEnter: onEnter, threshold: threshold })
    );
};

TableLoader.displayName = 'TableLoader';

TableLoader.propTypes = {
    id: PropTypes.any, // When key changes, we use a new waypoint
    onEnter: PropTypes.func,
    threshold: PropTypes.number
};

export default TableLoader;