import * as React from 'react';
import { injectIntl, FormattedMessage } from 'react-intl';
import classNames from 'classnames';

import IconClose from '../../../../icons/general/IconClose';
import Tooltip from '../../../../components/tooltip';
import IconAlertDefault from '../../../../icons/general/IconAlertDefault';
import SingleSelectField from '../../../../components/select-field/SingleSelectField';
import ValueField from './ValueField';

import messages from '../../messages';
import { ATTRIBUTE, COLUMN_DISPLAY_TEXT, COLUMN_KEY, OPERATOR, OPERATOR_DISPLAY_TEXT, OPERATOR_KEY, OPERATORS_FOR_ATTRIBUTE, VALUE, VALUE_DISPLAY_TEXT, VALUE_KEY } from '../../constants';


import '../../styles/FilterItem.scss';

var deleteButtonIconHeight = 18;
var deleteButtonIconWidth = 18;

var Condition = function Condition(_ref) {
    var areErrorsEnabled = _ref.areErrorsEnabled,
        columns = _ref.columns,
        condition = _ref.condition,
        deleteCondition = _ref.deleteCondition,
        index = _ref.index,
        formatMessage = _ref.intl.formatMessage,
        update = _ref.update;

    var onDeleteButtonClick = function onDeleteButtonClick() {
        deleteCondition(index);
    };

    var updateSelectedField = function updateSelectedField(option, fieldType) {
        var value = option.value;
        var valueType = option.type;
        var fieldId = option.fieldId || condition.fieldId;

        var displayText = option.displayText;
        var displayTextType = '',
            keyType = '';

        if (fieldType === ATTRIBUTE) {
            displayTextType = COLUMN_DISPLAY_TEXT;
            keyType = COLUMN_KEY;
        } else if (fieldType === OPERATOR) {
            displayTextType = OPERATOR_DISPLAY_TEXT;
            keyType = OPERATOR_KEY;
        } else if (fieldType === VALUE) {
            displayTextType = VALUE_DISPLAY_TEXT;
            keyType = VALUE_KEY;
        }

        update(index, condition, displayText, displayTextType, fieldId, value, keyType, valueType);
    };

    var getFormattedOptions = function getFormattedOptions(options) {
        return options.map(function (option, index) {
            return {
                displayText: option.displayName,
                fieldId: option.id,
                type: option.type,
                value: index
            };
        });
    };

    var getOperatorsForAttribute = function getOperatorsForAttribute(attribute) {
        var valueType = condition.valueType;

        if (valueType === '') {
            return [];
        }
        return OPERATORS_FOR_ATTRIBUTE[valueType];
    };

    var getValuesForAttribute = function getValuesForAttribute(attribute, columns) {
        var fieldId = condition.fieldId;

        var field = columns && columns.find(function (field) {
            return field.id === fieldId;
        });

        if (field && field.options) {
            var fieldOptions = field.options.map(function (option, index) {
                return {
                    displayName: option.key,
                    id: fieldId,
                    type: 'enum',
                    value: index
                };
            });

            return fieldOptions;
        }
        return [];
    };

    var updateValueField = function updateValueField(fieldValue) {
        var displayText = '';
        var displayTextType = VALUE_DISPLAY_TEXT;
        var fieldId = condition.fieldId;
        var value = '';
        var keyType = VALUE_KEY;
        var valueType = condition.valueType;
        if (!fieldValue || !fieldValue.target) {
            displayText = fieldValue;
            value = fieldValue;
        } else {
            var target = fieldValue.target;

            displayText = target.value;
            value = target.value;
        }

        update(index, condition, displayText, displayTextType, fieldId, value, keyType, valueType);
    };

    var getErrorMessage = function getErrorMessage() {
        var valueKey = condition.valueKey,
            valueType = condition.valueType;


        var isValueSet = valueKey !== null && valueKey !== '';

        var message = valueType === 'date' ? messages.tooltipSelectDateError : messages.tooltipSelectValueError;

        var error = areErrorsEnabled && !isValueSet ? formatMessage(message) : null;

        return error;
    };

    var renderDeleteButton = function renderDeleteButton() {
        return React.createElement(
            'div',
            { className: 'filter-item-delete-button' },
            React.createElement(
                'button',
                { className: 'delete-button', onClick: onDeleteButtonClick },
                React.createElement(IconClose, {
                    width: deleteButtonIconWidth,
                    height: deleteButtonIconHeight,
                    color: '#999EA4'
                })
            )
        );
    };

    var renderPrefixField = function renderPrefixField() {
        return React.createElement(
            'div',
            { className: 'filter-item-prefix-container' },
            React.createElement(
                'p',
                { className: 'filter-item-prefix-text' },
                React.createElement(FormattedMessage, messages.prefixButtonText)
            )
        );
    };

    var renderAttributeField = function renderAttributeField() {
        var columnKey = condition.columnKey;

        return React.createElement(
            'div',
            { className: 'filter-item-attribute-dropdown-container' },
            React.createElement(
                'div',
                { className: 'filter-dropdown-single-select-field-container' },
                React.createElement(SingleSelectField, {
                    fieldType: ATTRIBUTE,
                    isDisabled: false,
                    onChange: updateSelectedField,
                    options: attributeOptions,
                    placeholder: formatMessage(messages.selectAttributePlaceholderText),
                    selectedValue: columnKey
                })
            )
        );
    };

    var renderOperatorField = function renderOperatorField() {
        return React.createElement(
            'div',
            { className: 'filter-item-operator-dropdown-container' },
            React.createElement(
                'div',
                { className: 'filter-dropdown-single-select-field-container' },
                React.createElement(SingleSelectField, {
                    fieldType: OPERATOR,
                    isDisabled: false,
                    onChange: updateSelectedField,
                    options: operatorOptions,
                    selectedValue: operatorKey
                })
            )
        );
    };

    var renderValueField = function renderValueField() {
        var valueDisplayText = condition.valueDisplayText,
            valueKey = condition.valueKey,
            valueType = condition.valueType;


        var valuesForAttribute = getValuesForAttribute(valueDisplayText, columns);
        var valueOptions = getFormattedOptions(valuesForAttribute);

        var error = getErrorMessage();

        var classnames = classNames('filter-item-value-dropdown-container', {
            'show-error': error
        });

        return React.createElement(
            'div',
            { className: classnames },
            React.createElement(ValueField, {
                formatMessage: formatMessage,
                selectedValue: valueKey,
                updateValueField: updateValueField,
                updateSelectedField: updateSelectedField,
                valueKey: valueKey,
                valueOptions: valueOptions,
                valueType: valueType
            })
        );
    };

    var renderErrorIcon = function renderErrorIcon(error) {
        return error && React.createElement(
            'div',
            { className: 'filter-item-error-icon-status' },
            React.createElement(
                Tooltip,
                {
                    text: error || '',
                    position: 'middle-right',
                    theme: 'error'
                },
                React.createElement(
                    'span',
                    null,
                    React.createElement(IconAlertDefault, null)
                )
            )
        );
    };

    var columnDisplayText = condition.columnDisplayText,
        operatorKey = condition.operatorKey;

    var columnAttributes = columns || [];
    var attributeOptions = getFormattedOptions(columnAttributes);

    var operatorsForAttribute = getOperatorsForAttribute(columnDisplayText);
    var operatorOptions = getFormattedOptions(operatorsForAttribute);

    var error = getErrorMessage();

    return React.createElement(
        'div',
        { className: 'filter-item-container' },
        renderDeleteButton(),
        renderPrefixField(),
        renderAttributeField(),
        renderOperatorField(),
        renderValueField(),
        renderErrorIcon(error)
    );
};

Condition.propTypes = {
    condition: PropTypes.object.isRequired,
    deleteCondition: PropTypes.func.isRequired,
    areErrorsEnabled: PropTypes.bool.isRequired,
    index: PropTypes.number.isRequired,
    intl: PropTypes.object.isRequired,
    columns: PropTypes.arrayOf(function () {
        return (typeof bpfrpt_proptype_ColumnType === 'function' ? bpfrpt_proptype_ColumnType : PropTypes.shape(bpfrpt_proptype_ColumnType)).apply(this, arguments);
    }),
    update: PropTypes.func.isRequired
};
export { Condition as BaseCondition };
export default injectIntl(Condition);
import { bpfrpt_proptype_ColumnType } from '../../flowTypes';
import PropTypes from 'prop-types';