/**
 * 
 * @file Date and time utilities
 * @author Box
 */

var MILLISECONDS_PER_SECOND = 1000;
// 24 hours * 60 minutes * 60 seconds * 1000 milliseconds
var MILLISECONDS_PER_DAY = 24 * 60 * 60 * MILLISECONDS_PER_SECOND;
// 60 sec * 1000
var MILLISECONDS_PER_MINUTE = 60 * MILLISECONDS_PER_SECOND;

/**
 * Converts an integer value in seconds to milliseconds.
 * @param {number} seconds - The value in seconds
 * @returns {number} the value in milliseconds
 */
function convertToMs(seconds) {
    return seconds * MILLISECONDS_PER_SECOND;
}

/**
 * Checks whether the given date value (in unix milliseconds) is today.
 * @param {number|Date} dateValue - Date object or integer representing the number of milliseconds since 1/1/1970 UTC
 * @returns {boolean} whether the given value is today
 */
function isToday(dateValue) {
    var currentDate = new Date();
    var date = dateValue instanceof Date ? dateValue : new Date(dateValue);
    return currentDate.toDateString() === date.toDateString();
}

/**
 * Checks whether the given date value (in unix milliseconds) is yesterday.
 * @param {number} dateValue - Date object or integer or representing the number of milliseconds since 1/1/1970 UTC
 * @returns {boolean} wether the given value is yesterday
 */
function isYesterday(dateValue) {
    var date = dateValue instanceof Date ? dateValue.getTime() : dateValue;
    return isToday(date + MILLISECONDS_PER_DAY);
}

/**
 * Checks whether the given date value (in unix milliseconds) is tomorrow.
 * @param {number} dateValue - Date object or integer or representing the number of milliseconds since 1/1/1970 UTC
 * @returns {boolean} whether the given value is tomorrow
 */
function isTomorrow(dateValue) {
    var date = dateValue instanceof Date ? dateValue.getTime() : dateValue;
    return isToday(date - MILLISECONDS_PER_DAY);
}

/**
 * Checks whether the given date value (in unix milliseconds) is in the current year.
 * @param {number|Date} dateValue - Date object or integer representing the number of milliseconds since 1/1/1970 UTC
 * @returns {boolean} whether the given value is in the current year
 */
function isCurrentYear(dateValue) {
    var currentDate = new Date();
    var date = dateValue instanceof Date ? dateValue : new Date(dateValue);
    return currentDate.getFullYear() === date.getFullYear();
}

/**
 * Formats a number of seconds as a time string
 *
 * @param {number} seconds - seconds
 * @return {string} a string formatted like 3:57:35
 */
function formatTime(seconds) {
    var h = Math.floor(seconds / 3600);
    var m = Math.floor(seconds % 3600 / 60);
    var s = Math.floor(seconds % 3600 % 60);
    var hour = h > 0 ? h.toString() + ':' : '';
    var sec = s < 10 ? '0' + s.toString() : s.toString();
    var min = m.toString();
    if (h > 0 && m < 10) {
        min = '0' + min;
    }
    return '' + hour + min + ':' + sec;
}

/**
 * Adds time to a given dateValue
 *
 * @param {number|Date} dateValue - date or integer value to add time to
 * @param {number} timeToAdd - amount of time to add in ms
 * @return {number|Date} the modified date or integer
 */
function addTime(dateValue, timeToAdd) {
    if (dateValue instanceof Date) {
        return new Date(dateValue.getTime() + timeToAdd);
    }

    return dateValue + timeToAdd;
}

/**
 * Will convert
 *      2018-06-13T07:00:00.000Z
 * to
 *      2018-06-13T00:00:00.000Z
 *
 * This is the opposite of convertISOStringToUTCDate
 *
 * @param {Date} date
 * @return {number}
 */
function convertDateToUnixMidnightTime(date) {
    // date is localized to 00:00:00 at system/browser timezone
    var utcUnixTimeInMs = date.getTime();

    // timezone an integer offset; minutes behind GMT
    // we use the browser timezone offset instead of the user's,
    // because the datepicker uses the browser to get the "midnight"
    // time in the user's timezone with getTime()
    var timezoneOffsetInMins = date.getTimezoneOffset();
    var timezoneOffsetInMs = timezoneOffsetInMins * MILLISECONDS_PER_MINUTE;

    // we need the unix/epoch time for midnight on the date selected
    var unixDayMidnightTime = utcUnixTimeInMs - timezoneOffsetInMs;
    return unixDayMidnightTime;
}

/**
 * Will convert
 *      2018-06-13T00:00:00.000Z
 * to
 *      2018-06-13T07:00:00.000Z
 *
 * This is the opposite of convertDateToUnixMidnightTime
 *
 * @param {string} isoString - ISO string in UTC time zone
 */
function convertISOStringToUTCDate(isoString) {
    // get date in UTC midnight time
    var utcDate = new Date(isoString);
    var utcTime = utcDate.getTime();

    // get browser's timezone
    var timezoneOffsetInMins = utcDate.getTimezoneOffset();
    var timezoneOffsetInMs = timezoneOffsetInMins * MILLISECONDS_PER_MINUTE;

    // return date in utc timezone
    var localizedUnixTimeInMs = utcTime + timezoneOffsetInMs;
    return new Date(localizedUnixTimeInMs);
}

export { convertToMs, convertDateToUnixMidnightTime, convertISOStringToUTCDate, isToday, isTomorrow, isYesterday, isCurrentYear, formatTime, addTime };